"""AUTOGENERATED. DO NOT EDIT."""

from tf_keras.src.saving.object_registration import CustomObjectScope as custom_object_scope
from tf_keras.src.saving.object_registration import get_custom_objects
from tf_keras.src.saving.object_registration import get_registered_name
from tf_keras.src.saving.object_registration import get_registered_object
from tf_keras.src.saving.object_registration import register_keras_serializable
from tf_keras.src.saving.saving_api import load_model
from tf_keras.src.saving.saving_api import save_model
from tf_keras.src.saving.serialization_lib import deserialize_keras_object
from tf_keras.src.saving.serialization_lib import serialize_keras_object
